﻿using Android.App;
using Android.Widget;
using Android.OS;
using Com.Syncfusion.Charts;
using Android.Graphics;
using Android.Support.V7.App;
using Android.Views;
using Android.Renderscripts;
using System.Reflection;
using System.Collections.Generic;
using Android.Content;
using System;
using Java.Util;
using Android.Util;
using Android.Runtime;

namespace ChartSample
{
    [Activity(Label = "ChartSample", MainLauncher = true, Icon = "@drawable/icon", Theme = "@style/Theme.AppCompat")]
    public class MainActivity : AppCompatActivity
    {
		ChartExt chart;
        ViewModel viewModel;
        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);

            chart = new ChartExt(this);
            viewModel = new ViewModel();

            chart.SetBackgroundColor(Color.White);

			Calendar visibleMinimum = new GregorianCalendar(2010, 0, 1);
			Calendar visibleMaximum = new GregorianCalendar(2010, 0, 3);

			chart.PrimaryAxis = new DateTimeAxis();
            chart.SecondaryAxis = new NumericalAxis()
            {
				Minimum = 0,
				Maximum = 50,
            };

			chart.AnnotationX = new DateTime(2010, 1, 3);
			chart.AnnotationY = 5;

            ScatterSeries scatterSeries = new ScatterSeries();
            scatterSeries.ScatterHeight = 30;
            scatterSeries.ScatterWidth = 30;
			scatterSeries.ItemsSource = viewModel.DataPoints;
            scatterSeries.XBindingPath = "XValue";
            scatterSeries.YBindingPath = "YValue";
            chart.Series.Add(scatterSeries);
			ChartZoomPanBehavior behavior = new ChartZoomPanBehavior();
            chart.Behaviors.Add(behavior);
            SetContentView(chart);
        }
    }


	public class ChartExt : SfChart
	{
		void Image_Click(object sender, EventArgs e)
		{
			Toast.MakeText(this.Context,"Image has been clicked",ToastLength.Long).Show();
		}

		ImageView image;
		FrameLayout layout;

		public DateTime AnnotationX
		{
			get;
			set;
		}

		public double AnnotationY
		{
			get;
			set;
		}

		public ChartExt(Context context) : base(context)
        {
			float density = Resources.DisplayMetrics.Density;

			layout = new FrameLayout(context);

			image = new ImageView(Context)
			{
				LayoutParameters = new ViewGroup.LayoutParams(new FrameLayout.LayoutParams((int)(50 * density), (int)(50 * density)))
			};
			layout.AddView(image);
			layout.SetClipChildren(true);
			layout.SetClipToPadding(true);

			image.Click += Image_Click;;

			AddView(layout);
		}

		protected override void OnMeasure(int widthMeasureSpec, int heightMeasureSpec)
		{
			base.OnMeasure(widthMeasureSpec, heightMeasureSpec);

			layout.SetX(SeriesClipRect.Left);
			layout.SetY(SeriesClipRect.Top);

			layout.ClipBounds = new Rect(10, 10, (int)SeriesClipRect.Right-10, (int)SeriesClipRect.Bottom+10);

			image.SetImageResource(Resource.Drawable.Icon);
			float x = PrimaryAxis.ValueToPoint(AnnotationX.ToOADate()) - image.Width/2 + 10;
			float y = SecondaryAxis.ValueToPoint(AnnotationY) - image.Height / 2 + 10;
			image.SetX(x);
			image.SetY(y);					
		}

	}

}